/*!
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
// Utils
function checkNull(arr) {
    return !arr.some(v => v === null);
}
function convertArray(val, innerConverter) {
    if (Array.isArray(val))
        return convertArrayMembers(val, innerConverter);
    if (typeof val === 'string')
        return convertArrayMembers(val.split(','), innerConverter);
    const valConv = innerConverter(val);
    if (valConv !== null)
        return [valConv];
    return null;
}
function convertArrayMembers(valArr, innerConverter) {
    const strArr = valArr.map(v => innerConverter(v));
    if (checkNull(strArr))
        return strArr;
    else
        return null;
}
// Converters
function convertStringArray(val) {
    return convertArray(val, convertString);
}
exports.convertStringArray = convertStringArray;
function convertNumberArray(val) {
    return convertArray(val, convertNumber);
}
exports.convertNumberArray = convertNumberArray;
function convertDateArray(val) {
    return convertArray(val, convertDate);
}
exports.convertDateArray = convertDateArray;
function convertDate(val) {
    if (val instanceof Date)
        return val;
    if (typeof val === 'number')
        return new Date(val);
    if (typeof val === 'string')
        return new Date(val);
    return null;
}
exports.convertDate = convertDate;
function convertBoolean(val) {
    if (typeof val === 'boolean')
        return val;
    if (typeof val === 'number')
        return !!val;
    if (typeof val === 'string') {
        if (["t", "true", "y", "yes", "1"].some(s => val.localeCompare(s, undefined, { sensitivity: 'base' }) === 0))
            return true;
        if (["f", "false", "n", "no", "0"].some(s => val.localeCompare(s, undefined, { sensitivity: 'base' }) === 0))
            return false;
    }
    return null;
}
exports.convertBoolean = convertBoolean;
function convertString(val) {
    if (typeof val === 'string')
        return val;
    if (typeof val === 'number')
        return `${val}`;
    if (typeof val === 'boolean')
        return `${val}`;
    return null;
}
exports.convertString = convertString;
function convertNumber(val) {
    if (typeof val === 'number')
        return val;
    if (typeof val === 'boolean')
        return +val;
    if (typeof val === 'string') {
        const conv = parseFloat(val);
        if (!Number.isNaN(conv))
            return conv;
    }
    return null;
}
exports.convertNumber = convertNumber;
